@@ -33,15 +33,15 @@ var config = {
         name: "mysql",
         driver: "com.mysql.jdbc.Driver",
         url: "jdbc:mysql://db.codeunbug.com:3306/rmut_expert_db",
-        user: "xx",
-        password: "xx"
+        user: "root",
+        password: "ChangDao@2013"
       },
       {
         name: "mssql",
         driver: "com.microsoft.sqlserver.jdbc.SQLServerDriver",
-        url: "jdbc:sqlserver://202.44.34.86:1433;databaseName=RiceDB",
-        user: "xx",
-        password: "xx"
+        url: "jdbc:sqlserver://10.3.231.39:1433;databaseName=EdiDb",
+        user: "edi",
+        password: "edi@2017"
       },
       {
         name: "oracle",
