@@ -74,6 +74,47 @@ module.exports = function (app) {
         Object.assign(res, app.nylon.res);
         //  console.log(req);
 
+        req.r._Term.prototype.pager = function () {
+            // var url =req.baseUrl;// URL.parse(req.url, true).pathname;
+             //console.log(req);
+             var limit = 50;
+             var page = 1;
+ 
+             if (req.query._limit) {
+                 limit = parseInt(req.query._limit);
+                 page = parseInt(req.query._page);
+             }
+             else if (req.body._limit) {
+                 limit = parseInt(req.body._limit);
+                 page = parseInt(req.body._page);
+             }
+             else if (req.headers._limit) {
+                 limit = parseInt(req.headers._limit);
+                 page = parseInt(req.headers._page);
+             }
+             var skip = (limit * (page - 1));
+             var rowEnd = skip + limit;
+             var rowStart = skip + 1;
+ 
+             return this.do(function (data) {
+                 return r.branch(
+                     data.typeOf().eq('ARRAY'),
+                     {
+                         _totalCount: data.count(),
+                         _totalPage: r.ceil(data.count().div(limit)),
+                         _pageLimit: limit,
+                         _currentPage: page,
+                         _nextPage: r.branch(r.lt(data.count(), rowEnd).or(r.eq(data.count(), rowEnd)), page, page + 1),
+                         _rowStart: rowStart,
+                         _rowEnd: r.branch(r.lt(data.count(), rowEnd), data.count(), rowEnd),
+                         _option: 'pagination',
+                         data: data.skip(skip).limit(limit)
+                     }
+                     ,
+                     data
+                 )
+             })
+         };
 
         
         res.header("Access-Control-Allow-Origin", "*");
